TransactionColumns = {
  "orderNumber": "Номер заказа",
  "registerDate": "Дата",
  "ip": "IP-адрес",
  "mdOrder": "Уникальный номер заказа в системе",
  "paymentState": "Состояние",
  "merchantFullName": "Название продавца",
  "merchantLogin": "Логин продавца",
  "orderDescription": "Описание заказа",
  "amount": "Сумма",
  "paymentDate": "Дата оплаты",
  "depositedDate": "Дата списания",
  "refundedDate": "Дата последнего возврата",
  "reversedDate": "Дата отмены",
  "feeAmount": "Сумма комиссии",
  "currency": "Валюта",
  "approvedAmount": "Сумма предавторизации",
  "depositedAmount": "Сумма подтверждения",
  "refundedAmount": "Сумма возврата",
  "fraudWeight": "Вес фрода",
  "paymentWay": "Платежное средство",
  "cardholderName": "Имя владельца карты",
  "pan": "Номер карты",
  "expiry": "Дата окончания действия",
  "paymentSystem": "Платежная система",
  "product": "Продукт",
  "bankName": "Название Банка",
  "panCountryCode": "Код страны банка",
  "ipCountryCode": "Код страны IP-адреса",
  "panCountry": "Страна банка",
  "ipCountry": "Страна IP-адреса",
  "actionCode": "Код ответа процессинга",
  "actionCodeDescription": "Описание кода ответа процессинга",
  "originalActionCode": "Оригинальный код ответа процессинга",
  "approvalCode": "Approval Code",
  "authCode": "Auth code",
  "referenceNumber": "Reference number",
  "authReferenceNumber": "Authentication reference number",
  "terminalId": "Терминал",
  "processingId": "Процессинг",
  "transactionDesc": "3DSec/SSL",
  "eci": "ECI",
  "clientId": "Идентификатор клиента",
  "phone": "Телефон клиента",
  "email": "Email клиента",
  "orderParamsAsString": "Дополнительные параметры заказа",
  # extra columns
  "paymentStateDescription": "Описание состояния",
}

RefundColumns = {
  "id": "ID",
  "refundDate": "Дата возврата",
  "paymentDate": "Дата платежа",
  "merchantFullName": "Название продавца",
  "mdOrder": "ID заказа",
  "orderNumber": "Номер заказа",
  "amount": "Сумма возврата",
  "maskedPan": "Номер карты",
  "refundState": "Состояние возврата",
  "currencyName": "Валюта",
  "cardholder": "Держатель карты",
  "bankName": "Банк-эмитент",
  "countryName": "Страна банка-эмитента",
  "actionCode": "Код результата",
  "refNum": "Reference number",
  "processingId": "ID процессинга",
  "terminalId": "ID терминала",
  "paymentSystem": "МПС",
  "merchantMcc": "MCC"
}
